---
layout: template
title: Support
permalink: /support/
link_group: support
---
# Support

If you are having problems or questions, this section aims to help you.
Check out the subpages above.

In case you have found a potential bug or need help, please write issues on GitHub:

**[I have found a bug](https://github.com/postlund/pyatv/issues/new?assignees=&labels=bug&template=bug_report.md&title=)**

**[I need help](https://github.com/postlund/pyatv/issues/new?assignees=&labels=question&template=question-or-idea.md&title=)**

**[Something is missing...](https://github.com/postlund/pyatv/issues/new?assignees=&labels=feature&template=feature_request.md&title=)**